#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/11/27 14:52
# @Author  : lj
# @File    : headers_format.py
'''测试'''

def text():
    return '成功返回'

def run():
    print('成功')

if __name__ == '__main__':
    pass